DROP TABLE IF EXISTS commandqueue;
DROP TABLE IF EXISTS commandreply;
DROP TABLE IF EXISTS commands;
DROP TABLE IF EXISTS chanlog;
DROP TABLE IF EXISTS chban;
DROP TABLE IF EXISTS chan;
DROP TABLE IF EXISTS gline;
DROP TABLE IF EXISTS ison;
DROP TABLE IF EXISTS server;
DROP TABLE IF EXISTS user;
DROP TABLE IF EXISTS maxvalues;

CREATE TABLE commandqueue (
  commandid int unsigned NOT NULL,
  nickid int unsigned NOT NULL,
  KEY commandid (commandid),
  KEY nickid (nickid)
) TYPE=MyISAM;

CREATE TABLE commandreply (
  commandid int unsigned NOT NULL,
  reply text,
  KEY commandid (commandid)
) TYPE=MyISAM;

CREATE TABLE commands (
  commandid int unsigned NOT NULL auto_increment,
  source varchar(6) NOT NULL default '',
  command varchar(15) NOT NULL default '',
  target varchar(31) NOT NULL default '',
  params text,
  fsent enum('Y','N') NOT NULL default 'N',
  processed enum('Y','N') NOT NULL default 'N',
  reply enum('Y','N') NOT NULL default 'Y',
  linesexpecting int unsigned NOT NULL default '',
  PRIMARY KEY  (commandid)
) TYPE=MyISAM;

CREATE TABLE chanlog (
  logid int unsigned NOT NULL,
  chanid int unsigned NOT NULL default '0',
  time int unsigned NOT NULL default '',
  nick varchar(31) NOT NULL default '',
  message text,
  KEY logid (logid),
  KEY chanid (chanid)
) TYPE=MyISAM;

CREATE TABLE chban (
  banid int unsigned NOT NULL auto_increment,
  chanid int unsigned NOT NULL default '0',
  ban varchar(100) NOT NULL default '',
  PRIMARY KEY  (banid),
  KEY chanid (chanid)
) TYPE=MyISAM;

CREATE TABLE gline (
  glineid int unsigned NOT NULL auto_increment,
  gmask varchar(100) NOT NULL default '',
  expire int unsigned NOT NULL default '',
  lastmod int unsigned NOT NULL default '',
  reason text,
  PRIMARY KEY  (glineid)
) TYPE=MyISAM;

CREATE TABLE chan (
  chanid int unsigned NOT NULL auto_increment,
  channel varchar(201) binary NOT NULL default '',
  topic text,
  topicauthor varchar(31) default NULL,
  topictime datetime default NULL,
  mode_lb enum('Y','N') NOT NULL default 'N',
  mode_lc enum('Y','N') NOT NULL default 'N',
  mode_li enum('Y','N') NOT NULL default 'N',
  mode_lk enum('Y','N') NOT NULL default 'N',
  mode_ll enum('Y','N') NOT NULL default 'N',
  mode_lm enum('Y','N') NOT NULL default 'N',
  mode_ln enum('Y','N') NOT NULL default 'N',
  mode_lw enum('Y','N') NOT NULL default 'N',
  mode_l7 enum('Y','N') NOT NULL default 'N',
  mode_lp enum('Y','N') NOT NULL default 'N',
  mode_lr enum('Y','N') NOT NULL default 'N',      
  mode_ls enum('Y','N') NOT NULL default 'N',
  mode_lt enum('Y','N') NOT NULL default 'N',
  mode_ul enum('Y','N') NOT NULL default 'N',
  mode_um enum('Y','N') NOT NULL default 'N',
  mode_ur enum('Y','N') NOT NULL default 'N',
  mode_uo enum('Y','N') NOT NULL default 'N',
  mode_ll_data int(10) NOT NULL default '0',
  mode_lk_data varchar(23) NOT NULL default '',
  PRIMARY KEY  (chanid),
  UNIQUE KEY channel (channel)
) TYPE=MyISAM;

CREATE TABLE ison (
  nickid int unsigned NOT NULL default '0',
  chanid int unsigned NOT NULL default '0',
  mode_lo enum('Y','N') NOT NULL default 'N',
  mode_lv enum('Y','N') NOT NULL default 'N',
  PRIMARY KEY  (nickid,chanid),
  KEY nickid (nickid),
  KEY chanid (chanid)
) TYPE=MyISAM;

CREATE TABLE server (
  servid int unsigned NOT NULL auto_increment,
  server varchar(64) NOT NULL default '',
  snumeric varchar(64) NOT NULL default '',
  comment varchar(255) NOT NULL default '',
  linkedto int unsigned default NULL,
  connecttime datetime default NULL,
  online enum('Y','N') NOT NULL DEFAULT 'Y',
  lastsplit datetime default NULL,
  PRIMARY KEY  (servid),
  UNIQUE KEY server (server),
  KEY linkedto (linkedto)
) TYPE=MyISAM;


CREATE TABLE user (
  nickid int unsigned NOT NULL auto_increment,
  nick varchar(31) NOT NULL default '',
  snumeric varchar(31) NOT NULL default '',
  account varchar(31) NOT NULL default '',
  acctimestamp int unsigned NOT NULL default '',
  realname varchar(51) NOT NULL default '',
  hostname varchar(64) NOT NULL default '',
  ipaddr varchar(16) NOT NULL default '',
  username varchar(11) NOT NULL default '',
  connecttime datetime NOT NULL default '0000-00-00 00:00:00',
  servid int unsigned NOT NULL default '0',
  away enum('Y','N') NOT NULL default 'N',
  awaymsg text,
  online enum('Y','N') NOT NULL DEFAULT 'Y',
  lastquit datetime default NULL,
  mode_ld enum('Y','N') NOT NULL default 'N',  
  mode_li enum('Y','N') NOT NULL default 'N',
  mode_lo enum('Y','N') NOT NULL default 'N',
  mode_ls enum('Y','N') NOT NULL default 'N',
  mode_lw enum('Y','N') NOT NULL default 'N',
  mode_lk enum('Y','N') NOT NULL default 'N',
  mode_lg enum('Y','N') NOT NULL default 'N',
  mode_lx enum('Y','N') NOT NULL default 'N',
  mode_lr enum('Y','N') NOT NULL default 'N',
  PRIMARY KEY  (nickid),
  UNIQUE KEY nick (nick),
  KEY servid (servid)
) TYPE=MyISAM;

CREATE TABLE maxvalues (
  type varchar(10) NOT NULL default '',
  val int unsigned NOT NULL default '0',
  time datetime NOT NULL default '0000-00-00 00:00:00',
  PRIMARY KEY(type)
) TYPE=MyISAM;
